import React, { useState } from "react";
import { motion } from "framer-motion";
import { MessageCircle, Phone, Users } from "lucide-react";
import EcoMinimalHeroSection from "@/components/home/EcoMinimalHeroSection";
import EcoMinimalAboutSection from "@/components/home/EcoMinimalAboutSection";
import EcoMinimalProductSection from "@/components/home/EcoMinimalProductSection";
import VideoTestimonialsSection from "@/components/home/VideoTestimonialsSection";
import DealerLocator from "@/components/home/DealerLocator";
import BrochureSection from "@/components/home/BrochureSection";
import FinancingPartners from "@/components/home/FinancingPartners";
import NewsEventsSection from "@/components/home/NewsEventsSection";
import ContactSection from "@/components/home/ContactSection";
import Navbar from "@/components/layout/Navbar";
import Footer from "@/components/layout/Footer";
import PageTransition from "@/components/layout/PageTransition";
import ConnectWithUsPopup from "@/components/ui/ConnectWithUsPopup";
import SEOHead from "@/components/seo/SEOHead";

const Home = () => {
  const [isConnectPopupOpen, setIsConnectPopupOpen] = useState(false);

  const handleWhatsAppClick = () => {
    const phoneNumber = "919201987206";
    const message = "Hello! I'm interested in your electric vehicles. Can you provide more information?";
    const whatsappUrl = `https://wa.me/${phoneNumber}?text=${encodeURIComponent(message)}`;
    window.open(whatsappUrl, '_blank');
  };

  const handlePhoneClick = () => {
    window.open('tel:+919201987206', '_self');
  };

  return (
    <PageTransition>
      <SEOHead 
        title=""
        description="Luxus Green Mobility - India's No.1 Electric Auto Manufacturer. Leading manufacturer of premium electric three-wheelers for sustainable urban mobility. Eco-friendly commercial and passenger vehicles with zero emissions."
        keywords="electric three wheeler, electric vehicle, eco-friendly transport, sustainable mobility, zero emission vehicle, commercial EV, passenger EV, LUXUS GREEN, India electric auto"
      />
      <div className="min-h-screen bg-white">
        <Navbar />
        <main className="overflow-hidden">
          <EcoMinimalHeroSection />
          <EcoMinimalAboutSection />
          <EcoMinimalProductSection />
          <VideoTestimonialsSection />
          <DealerLocator />
          <BrochureSection />
          <FinancingPartners />
          <NewsEventsSection />
          <ContactSection />
        </main>
        <Footer />

        {/* Modern Floating Contact Icons - Always Visible Throughout Scroll */}
        <motion.div 
          className="fixed right-4 md:right-6 bottom-4 md:bottom-6 z-[9999] flex flex-col gap-3"
          initial={{ scale: 0, opacity: 0, x: 100 }}
          animate={{ scale: 1, opacity: 1, x: 0 }}
          transition={{ delay: 2, duration: 0.8, type: "spring", stiffness: 150 }}
        >
          {/* WhatsApp Icon */}
          <motion.button
            onClick={handleWhatsAppClick}
            className="group relative w-16 h-16 bg-gradient-to-r from-green-500 to-green-600 text-white rounded-full shadow-2xl flex items-center justify-center overflow-hidden border-2 border-white/20"
            whileHover={{ 
              scale: 1.15,
              rotate: 10,
              y: -5
            }}
            whileTap={{ scale: 0.9 }}
            title="Chat on WhatsApp - +91 92019 87206"
            style={{
              filter: "drop-shadow(0 10px 20px rgba(34, 197, 94, 0.3))"
            }}
          >
            {/* Background Glow Effect */}
            <motion.div
              className="absolute inset-0 bg-gradient-to-r from-green-400 to-green-500 opacity-0 group-hover:opacity-100 transition-opacity duration-300 rounded-full"
              initial={false}
            />

            {/* Icon */}
            <MessageCircle className="w-7 h-7 relative z-10 drop-shadow-sm" />

            {/* Continuous Pulse Animation */}
            <motion.div
              className="absolute inset-0 rounded-full border-2 border-green-300"
              animate={{
                scale: [1, 1.8, 1],
                opacity: [0.8, 0, 0.8],
              }}
              transition={{
                duration: 2.5,
                repeat: Infinity,
                ease: "easeInOut"
              }}
            />

            {/* Secondary Pulse */}
            <motion.div
              className="absolute inset-0 rounded-full border-2 border-green-400"
              animate={{
                scale: [1, 1.5, 1],
                opacity: [0.6, 0, 0.6],
              }}
              transition={{
                duration: 2.5,
                repeat: Infinity,
                ease: "easeInOut",
                delay: 0.5
              }}
            />
          </motion.button>

          {/* Phone Icon */}
          <motion.button
            onClick={handlePhoneClick}
            className="group relative w-16 h-16 bg-gradient-to-r from-blue-500 to-blue-600 text-white rounded-full shadow-2xl flex items-center justify-center overflow-hidden border-2 border-white/20"
            whileHover={{ 
              scale: 1.15,
              rotate: -10,
              y: -5
            }}
            whileTap={{ scale: 0.9 }}
            title="Call us - +91 92019 87206"
            style={{
              filter: "drop-shadow(0 10px 20px rgba(59, 130, 246, 0.3))"
            }}
          >
            {/* Background Glow Effect */}
            <motion.div
              className="absolute inset-0 bg-gradient-to-r from-blue-400 to-blue-500 opacity-0 group-hover:opacity-100 transition-opacity duration-300 rounded-full"
              initial={false}
            />

            {/* Icon with Shake Animation */}
            <motion.div
              animate={{ 
                rotate: [0, -5, 5, -5, 0],
              }}
              transition={{
                duration: 3,
                repeat: Infinity,
                ease: "easeInOut"
              }}
            >
              <Phone className="w-7 h-7 relative z-10 drop-shadow-sm" />
            </motion.div>

            {/* Continuous Pulse Animation */}
            <motion.div
              className="absolute inset-0 rounded-full border-2 border-blue-300"
              animate={{
                scale: [1, 1.8, 1],
                opacity: [0.8, 0, 0.8],
              }}
              transition={{
                duration: 2.5,
                repeat: Infinity,
                ease: "easeInOut",
                delay: 0.8
              }}
            />

            {/* Secondary Pulse */}
            <motion.div
              className="absolute inset-0 rounded-full border-2 border-blue-400"
              animate={{
                scale: [1, 1.5, 1],
                opacity: [0.6, 0, 0.6],
              }}
              transition={{
                duration: 2.5,
                repeat: Infinity,
                ease: "easeInOut",
                delay: 1.3
              }}
            />
          </motion.button>

          {/* Partner With Us Icon */}
          <motion.a
            href='/connect-now'
            className="group relative w-16 h-16 bg-gradient-to-r from-purple-500 to-purple-600 text-white rounded-full shadow-2xl flex items-center justify-center overflow-hidden border-2 border-white/20"
            whileHover={{ 
              scale: 1.15,
              rotate: 5,
              y: -5
            }}
            whileTap={{ scale: 0.9 }}
            title="Partner With Us - Connect Now"
            style={{
              filter: "drop-shadow(0 10px 20px rgba(147, 51, 234, 0.3))"
            }}
          >
            {/* Background Glow Effect */}
            <motion.div
              className="absolute inset-0 bg-gradient-to-r from-purple-400 to-purple-500 opacity-0 group-hover:opacity-100 transition-opacity duration-300 rounded-full"
              initial={false}
            />

            {/* Icon */}
            <Users className="w-7 h-7 relative z-10 drop-shadow-sm" />

            {/* Continuous Pulse Animation */}
            <motion.div
              className="absolute inset-0 rounded-full border-2 border-purple-300"
              animate={{
                scale: [1, 1.8, 1],
                opacity: [0.8, 0, 0.8],
              }}
              transition={{
                duration: 2.5,
                repeat: Infinity,
                ease: "easeInOut",
                delay: 1
              }}
            />

            {/* Secondary Pulse */}
            <motion.div
              className="absolute inset-0 rounded-full border-2 border-purple-400"
              animate={{
                scale: [1, 1.5, 1],
                opacity: [0.6, 0, 0.6],
              }}
              transition={{
                duration: 2.5,
                repeat: Infinity,
                ease: "easeInOut",
                delay: 1.5
              }}
            />
          </motion.a>

          {/* Floating Background Blob */}
          <motion.div
            className="absolute -inset-4 bg-gradient-to-r from-green-500/10 to-blue-500/10 rounded-3xl blur-xl -z-10"
            animate={{
              scale: [1, 1.1, 1],
              rotate: [0, 5, -5, 0],
            }}
            transition={{
              duration: 4,
              repeat: Infinity,
              ease: "easeInOut"
            }}
          />
        </motion.div>

        {/* Connect With Us Popup */}
        <ConnectWithUsPopup 
          isOpen={isConnectPopupOpen} 
          onClose={() => setIsConnectPopupOpen(false)} 
        />
      </div>
    </PageTransition>
  );
};

export default Home;